==> dklibs-1.23.1.tar.gz: dklibs-1.23.1/dksdbii.h <==
/*
Copyright (c) 2007, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  its contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/

#ifndef DKBSDII_H
#define DKBSDII_H	1

#include <dk.h>

#if DK_HAVE_STDLIB_H
#include <stdlib.h>
#endif
#if DK_HAVE_ALLOC_H
#include <alloc.h>
#endif
#if DK_HAVE_MALLOC_H
#include <malloc.h>
#endif

typedef struct {
  char	*buffer;	/* file name buffer		*/
  char	*fn;		/* file name, part of buffer	*/
  int	tp;		/* BDB, NDBM or GDBM		*/
  int	acc;		/* READ, WRITE, RDWR		*/
  int	fm;		/* file permissions		*/
  int	did_truncate;	/* file was already truncated	*/
  mode_t	tfm;	/* translated file permissions	*/
  int	blksize;	/* block size (for GDBM)	*/
  void	*dbptr;		/* pointer to the real database	*/
} dk_sdbi_db;



/*
	BDB module
*/
#if defined(EXTERN)
#undef EXTERN
#endif
#if DKSDBI_BDB
#define EXTERN /* nix */
#else
#if DK_HAVE_PROTOTYPES
#define EXTERN /* nix */
#else
#define EXTERN extern
#endif
#endif
#if DK_HAVE_DB_H
#if defined(__cplusplus)
extern "C" {
#endif
EXTERN int
dksdbi_bdb_close DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_bdb_open DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_bdb_store DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t vl, int insmod));
EXTERN int
dksdbi_bdb_delete DK_PR((dk_sdbi_db *p, char *k, size_t kl));
EXTERN int
dksdbi_bdb_fetch DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t *vl));
EXTERN int
dksdbi_bdb_string_fetch DK_PR((dk_sdbi_db *p, char *k, char *v, size_t s));
EXTERN int
dksdbi_bdb_traverse DK_PR((dk_sdbi_db *p, void *d, dk_sdbi_fct_t *f));
EXTERN int
dksdbi_bdb_sync DK_PR((dk_sdbi_db *p));
#if defined(__cplusplus)
}
#endif
#endif



/*
	NDBM module
*/
#if defined(EXTERN)
#undef EXTERN
#endif
#if DKSDBI_NDBM
#define EXTERN /* nix */
#else
#if DK_HAVE_PROTOTYPES
#define EXTERN /* nix */
#else
#define EXTERN extern
#endif
#endif
#if DK_HAVE_NDBM_H
#if defined(__cplusplus)
extern "C" {
#endif
EXTERN int
dksdbi_ndbm_close DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_ndbm_open DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_ndbm_store DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t vl, int insmod));
EXTERN int
dksdbi_ndbm_delete DK_PR((dk_sdbi_db *p, char *k, size_t kl));
EXTERN int
dksdbi_ndbm_fetch DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t *vl));
EXTERN int
dksdbi_ndbm_string_fetch DK_PR((dk_sdbi_db *p, char *k, char *v, size_t s));
EXTERN int
dksdbi_ndbm_traverse DK_PR((dk_sdbi_db *p, void *d, dk_sdbi_fct_t *f));
EXTERN int
dksdbi_ndbm_sync DK_PR((dk_sdbi_db *p));
#if defined(__cplusplus)
}
#endif
#endif



/*
	GDBM module
*/
#if defined(EXTERN)
#undef EXTERN
#endif
#if DKSDBI_GDBM
#define EXTERN /* nix */
#else
#if DK_HAVE_PROTOTYPES
#define EXTERN /* nix */
#else
#define EXTERN extern
#endif
#endif
#if DK_HAVE_GDBM_H
#if defined(__cplusplus)
extern "C" {
#endif
EXTERN int
dksdbi_gdbm_close DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_gdbm_open DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_gdbm_store DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t vl, int insmod));
EXTERN int
dksdbi_gdbm_delete DK_PR((dk_sdbi_db *p, char *k, size_t kl));
EXTERN int
dksdbi_gdbm_fetch DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t *vl));
EXTERN int
dksdbi_gdbm_string_fetch DK_PR((dk_sdbi_db *p, char *k, char *v, size_t s));
EXTERN int
dksdbi_gdbm_traverse DK_PR((dk_sdbi_db *p, void *d, dk_sdbi_fct_t *f));
EXTERN int
dksdbi_gdbm_sync DK_PR((dk_sdbi_db *p));
#if defined(__cplusplus)
}
#endif
#endif

#endif

==> dklibs-1.26.0.tar.gz: dklibs-1.26.0/dksdbii.h <==
/*
Copyright (c) 2007, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/

#ifndef DKBSDII_H
#define DKBSDII_H	1

#include <dk.h>

#if DK_HAVE_STDLIB_H
#include <stdlib.h>
#endif
#if DK_HAVE_ALLOC_H
#include <alloc.h>
#endif
#if DK_HAVE_MALLOC_H
#include <malloc.h>
#endif

typedef struct {
  char	*buffer;	/* file name buffer		*/
  char	*fn;		/* file name, part of buffer	*/
  int	tp;		/* BDB, NDBM or GDBM		*/
  int	acc;		/* READ, WRITE, RDWR		*/
  int	fm;		/* file permissions		*/
  int	did_truncate;	/* file was already truncated	*/
  mode_t	tfm;	/* translated file permissions	*/
  int	blksize;	/* block size (for GDBM)	*/
  void	*dbptr;		/* pointer to the real database	*/
} dk_sdbi_db;



/*
	BDB module
*/
#if defined(EXTERN)
#undef EXTERN
#endif
#if DKSDBI_BDB
#define EXTERN /* nix */
#else
#if DK_HAVE_PROTOTYPES
#define EXTERN /* nix */
#else
#define EXTERN extern
#endif
#endif
#if DK_HAVE_DB_H
#if defined(__cplusplus)
extern "C" {
#endif
EXTERN int
dksdbi_bdb_close DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_bdb_open DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_bdb_store DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t vl, int insmod));
EXTERN int
dksdbi_bdb_delete DK_PR((dk_sdbi_db *p, char *k, size_t kl));
EXTERN int
dksdbi_bdb_fetch DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t *vl));
EXTERN int
dksdbi_bdb_string_fetch DK_PR((dk_sdbi_db *p, char *k, char *v, size_t s));
EXTERN int
dksdbi_bdb_traverse DK_PR((dk_sdbi_db *p, void *d, dk_sdbi_fct_t *f));
EXTERN int
dksdbi_bdb_sync DK_PR((dk_sdbi_db *p));
#if defined(__cplusplus)
}
#endif
#endif



/*
	NDBM module
*/
#if defined(EXTERN)
#undef EXTERN
#endif
#if DKSDBI_NDBM
#define EXTERN /* nix */
#else
#if DK_HAVE_PROTOTYPES
#define EXTERN /* nix */
#else
#define EXTERN extern
#endif
#endif
#if DK_HAVE_NDBM_H
#if defined(__cplusplus)
extern "C" {
#endif
EXTERN int
dksdbi_ndbm_close DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_ndbm_open DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_ndbm_store DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t vl, int insmod));
EXTERN int
dksdbi_ndbm_delete DK_PR((dk_sdbi_db *p, char *k, size_t kl));
EXTERN int
dksdbi_ndbm_fetch DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t *vl));
EXTERN int
dksdbi_ndbm_string_fetch DK_PR((dk_sdbi_db *p, char *k, char *v, size_t s));
EXTERN int
dksdbi_ndbm_traverse DK_PR((dk_sdbi_db *p, void *d, dk_sdbi_fct_t *f));
EXTERN int
dksdbi_ndbm_sync DK_PR((dk_sdbi_db *p));
#if defined(__cplusplus)
}
#endif
#endif



/*
	GDBM module
*/
#if defined(EXTERN)
#undef EXTERN
#endif
#if DKSDBI_GDBM
#define EXTERN /* nix */
#else
#if DK_HAVE_PROTOTYPES
#define EXTERN /* nix */
#else
#define EXTERN extern
#endif
#endif
#if DK_HAVE_GDBM_H
#if defined(__cplusplus)
extern "C" {
#endif
EXTERN int
dksdbi_gdbm_close DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_gdbm_open DK_PR((dk_sdbi_db *p));
EXTERN int
dksdbi_gdbm_store DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t vl, int insmod));
EXTERN int
dksdbi_gdbm_delete DK_PR((dk_sdbi_db *p, char *k, size_t kl));
EXTERN int
dksdbi_gdbm_fetch DK_PR((dk_sdbi_db *p, void *kp, size_t kl, void *vp, size_t *vl));
EXTERN int
dksdbi_gdbm_string_fetch DK_PR((dk_sdbi_db *p, char *k, char *v, size_t s));
EXTERN int
dksdbi_gdbm_traverse DK_PR((dk_sdbi_db *p, void *d, dk_sdbi_fct_t *f));
EXTERN int
dksdbi_gdbm_sync DK_PR((dk_sdbi_db *p));
#if defined(__cplusplus)
}
#endif
#endif

#endif
